.. JSON Time Series (JTS) for Python documentation master file, created by
   sphinx-quickstart on Sun May  7 14:38:02 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to JSON Time Series (JTS) for Python's documentation!
=============================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/api/jts

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
